@@ -29,9 +29,9 @@ def run_cli() -> None:
         args.seasonal: SeasonalCli,
         args.history: HistoryCli,
         args.mal: MalCli,
-        args.auto_update: SeasonalCli
+        args.auto_update: SeasonalCli,
     }
 
     cli_class = clis_dict.get(True, DefaultCli)
 
-    cli_class(options=args, rpc_client=rpc_client).run()
\ No newline at end of file
+    cli_class(options=args, rpc_client=rpc_client).run()
