@@ -97,9 +97,10 @@ class MAL:
     def auto_map_all_without_map(self):
         with Pool(processes=None) as pool:
             mal_entries = self.local_mal_list_json["data"]
-            # apply the search function to each search value in parallel
+                # apply the search function to each search value in parallel
             results = pool.map(self.auto_map_gogo_mal, mal_entries, True)
 
+
         new_mal_entries = list()
         for result in results:
             if type(result) is dict:
@@ -556,55 +557,59 @@ class MAL:
             print(f"{colors.GREEN}Done.{colors.END}")
 
     def auto_map_gogo_mal(self, mal_entry, mp=False):
-        if "gogo_map" in mal_entry and len(mal_entry["gogo_map"]) > 0:
-            return {"failed_to_map": False, "mal_entry": mal_entry}
-        failed_to_map = True
-        cprint(colors.GREEN, "Auto mapping: ", colors.BLUE, mal_entry["node"]["title"])
+        # Look issue 122
+        try:
+            if "gogo_map" in mal_entry and len(mal_entry["gogo_map"]) > 0:
+                return {"failed_to_map": False, "mal_entry": mal_entry}
+            failed_to_map = True
+            cprint(colors.GREEN, "Auto mapping: ", colors.BLUE, mal_entry["node"]["title"])
 
-        search_values = [
-            mal_entry["node"]["title"],
-            mal_entry["node"]["alternative_titles"]["en"],
-        ] + mal_entry["node"]["alternative_titles"]["synonyms"]
+            search_values = [
+                mal_entry["node"]["title"],
+                mal_entry["node"]["alternative_titles"]["en"],
+            ] + mal_entry["node"]["alternative_titles"]["synonyms"]
 
-        found = {}
-        for search in search_values:
-            query_class = query(search, Entry)
-            query_class.get_pages()
-            found["search"] = query_class.get_links()
+            found = {}
+            for search in search_values:
+                query_class = query(search, Entry)
+                query_class.get_pages()
+                found["search"] = query_class.get_links()
 
-            if found["search"] == 0:
-                self.shows_failed_automap.add(mal_entry["node"]["title"])
-                continue
-            if "gogo_map" not in mal_entry:
-                mal_entry["gogo_map"] = []
-            for i, anime in enumerate(found["search"][1]):
-                if any(
-                    anime.lower().rstrip("(dub)").rstrip("(japanese dub)").strip(" ")
-                    in show.lower()
-                    for show in [search_values[0], search_values[1]]
-                ):
-                    gogo_map = mal_entry["gogo_map"]
-                    current_map = self.make_gogo_map(found["search"][0][i], anime)
+                if found["search"] == 0:
+                    self.shows_failed_automap.add(mal_entry["node"]["title"])
+                    continue
+                if "gogo_map" not in mal_entry:
+                    mal_entry["gogo_map"] = []
+                for i, anime in enumerate(found["search"][1]):
+                    if any(
+                        anime.lower().rstrip("(dub)").rstrip("(japanese dub)").strip(" ")
+                        in show.lower()
+                        for show in [search_values[0], search_values[1]]
+                    ):
+                        gogo_map = mal_entry["gogo_map"]
+                        current_map = self.make_gogo_map(found["search"][0][i], anime)
 
-                    self.update_gogo_map_list(gogo_map, current_map)
-                    failed_to_map = False
-                    if not mp:
-                        self.shows_failed_automap.discard(mal_entry["node"]["title"])
-                    self.update_anime_list(
-                        mal_entry["node"]["id"],
-                        {
-                            "num_watched_episodes": mal_entry["node"]["my_list_status"][
-                                "num_episodes_watched"
-                            ],
-                            "tags": "anipy-cli",
-                        },
-                    )
-                else:
-                    if not mp:
-                        self.shows_failed_automap.add(mal_entry["node"]["title"])
-        if mp:
-            self.write_save_data()
-        return {"failed_to_map": failed_to_map, "mal_entry": mal_entry}
+                        self.update_gogo_map_list(gogo_map, current_map)
+                        failed_to_map = False
+                        if not mp:
+                            self.shows_failed_automap.discard(mal_entry["node"]["title"])
+                        self.update_anime_list(
+                            mal_entry["node"]["id"],
+                            {
+                                "num_watched_episodes": mal_entry["node"]["my_list_status"][
+                                    "num_episodes_watched"
+                                ],
+                                "tags": "anipy-cli",
+                            },
+                        )
+                    else:
+                        if not mp:
+                            self.shows_failed_automap.add(mal_entry["node"]["title"])
+            if mp:
+                self.write_save_data()
+            return {"failed_to_map": failed_to_map, "mal_entry": mal_entry}
+        except json.JSONDecodeError:
+            return {"failed_to_map": True, "mal_entry": mal_entry}
 
     def manual_map_gogo_mal(self, mal_anime_name: str, gogo: dict):
         mal_entry = [
