@@ -3,7 +3,7 @@ from anipy_cli.config import Config
 
 
 class Mpv(SubProcessPlayerBase):
-    def __init__(self, rpc_client=None, mpv_exec_name: str = "mpv"):
+    def __init__(self, player_path: str, rpc_client=None):
         player_args_template = [
             "{stream_url}",
             "--force-media-title={media_title}",
@@ -14,6 +14,6 @@ class Mpv(SubProcessPlayerBase):
 
         super().__init__(
             player_args_template=player_args_template,
+            player_path=player_path,
             rpc_client=rpc_client,
-            player_exec=mpv_exec_name,
         )
