@@ -3,7 +3,7 @@ from anipy_cli.config import Config
 
 
 class Syncplay(SubProcessPlayerBase):
-    def __init__(self, rpc_client=None):
+    def __init__(self, player_path: str, rpc_client=None):
         self.player_exec = "syncplay"
         player_args_template = [
             "--" "--http-referrer='{embed_url}'",
@@ -14,6 +14,6 @@ class Syncplay(SubProcessPlayerBase):
 
         super().__init__(
             rpc_client=rpc_client,
-            player_exec=self.player_exec,
+            player_path=player_path,
             player_args_template=player_args_template,
         )
