@@ -3,7 +3,7 @@ from anipy_cli.config import Config
 
 
 class Vlc(SubProcessPlayerBase):
-    def __init__(self, rpc_client=None):
+    def __init__(self, player_path: str, rpc_client=None):
         player_args_template = [
             "--http-referrer='{embed_url}'",
             "--meta-title='{media_title}'",
@@ -13,6 +13,6 @@ class Vlc(SubProcessPlayerBase):
 
         super().__init__(
             rpc_client=rpc_client,
+            player_path=player_path,
             player_args_template=player_args_template,
-            player_exec="vlc",
         )
