@@ -175,12 +175,12 @@ class epHandler:
 
         while True:
             which_episode = self._do_prompt(
-                "Last Episode you watched (put 0 to start at the beginning) "
+                "Last Episode you watched (put -1 to start at the beginning) "
             )
             try:
-                if self._validate_ep(which_episode) or int(which_episode) == 0:
+                if self._validate_ep(which_episode) or int(which_episode) == -1:
                     self.entry.ep = int(which_episode)
-                    if int(which_episode) != 0:
+                    if int(which_episode) != -1:
                         self.gen_eplink()
                     else:
                         self.entry.ep_url = None
@@ -298,7 +298,7 @@ class videourl:
         soup = BeautifulSoup(r.content, "html.parser")
         link = soup.find("a", {"class": "active", "rel": "1"})
         loc_err(link, self.entry.ep_url, "embed-url")
-        self.entry.embed_url = f'https:{link["data-video"]}'
+        self.entry.embed_url = f'https:{link["data-video"]}' if not link["data-video"].startswith("https:") else link["data-video"]
 
     @functools.lru_cache()
     def get_enc_keys(self):
